pub struct PartneredSmallParcelPackageOutput {
    pub dimensions: Box<Dimensions>,
    pub weight: Box<Weight>,
    pub carrier_name: String,
    pub tracking_id: String,
    pub package_status: PackageStatus,
}
PartneredSmallParcelPackageOutput : Dimension, weight, and shipping information for the package.

Fields

dimensions: Box<Dimensions>weight: Box<Weight>carrier_name: String

The carrier specified with a previous call to putTransportDetails.

tracking_id: String

The tracking number of the package, provided by the carrier.

package_status: PackageStatus

Implementations

Dimension, weight, and shipping information for the package.